@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Patch.py 9439 2015-09-25 08:01:30Z Eric $
+# $Id: Patch.py 9927 2017-04-29 14:17:02Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,28 +11,43 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2015-09-25 16:01:30 +0800 (Fri, 25 Sep 2015) $
-# $Revision: 9439 $
+# $Author: David $ (last)
+# $Date: 2017-04-29 22:17:02 +0800 (Sat, 29 Apr 2017) $
+# $Revision: 9927 $
 #
 # Contributors:
 #  Bear
 #  Yachu
 
-import os
+from Util import update, populateEnvToSettings
 
-from Iuppiter.Function import enhance
-
-from Iuno import DJANGO_VERSION
-
-def attachDebugSettings(settingsLocals):
+def attachDebugSettings(settingsDict):
     """
     Attach debug related settings to settings.py.
     It must be called in settings by passing locals().
 
     @param settingsLocals locals() in settings.py.
     """
-    pass
+
+    # debug tool bar & django extensions
+    try:
+        import debug_toolbar
+        import django_extensions
+    except ImportError:
+        pass
+    else:
+        settingsDict['INSTALLED_APPS'] += ['django_extensions',]
+        settingsDict['INSTALLED_APPS'] += ['debug_toolbar', ]
+        settingsDict['MIDDLEWARE_CLASSES'] += (
+            "debug_toolbar.middleware.DebugToolbarMiddleware", )
+        defaultInternalIP = {
+            'INTERNAL_IPS': ['127.0.0.1'],
+        }
+        update(settingsDict, defaultInternalIP)
+        
+        populateEnvToSettings((
+            'INTERNAL_IPS',
+        ), settingsDict)
 
 def extendSettings(settingsLocals):
     """
@@ -147,7 +162,17 @@ def attachDebugURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
-    pass
+    from django.conf.urls import url, include, patterns
+
+    try:
+        import debug_toolbar
+    except:
+        pass
+    else:
+        if settings.DEBUG:
+            urlpatterns += patterns('',
+                url(r'^__debug__/', include(debug_toolbar.urls)),
+            )
 
 def attachURLs(settings, urlpatterns):
     """
@@ -157,7 +182,14 @@ def attachURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
-    pass
+    from django.conf.urls import url, include, patterns
+
+    if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
+        urlpatterns += patterns('',
+            url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
+                'document_root': settings.MEDIA_ROOT,
+            })
+    )
 
 # http://www.arthurkoziel.com/2009/01/15/
 # passing-mediaurl-djangos-500-error-view/
