@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9897 2017-04-23 05:53:37Z David $
+# $Id: __init__.py 9927 2017-04-29 14:17:02Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,17 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-23 13:53:37 +0800 (Sun, 23 Apr 2017) $
-# $Revision: 9897 $
+# $Date: 2017-04-29 22:17:02 +0800 (Sat, 29 Apr 2017) $
+# $Revision: 9927 $
 
 import os
 import sys
 import warnings
 import importlib
 
+from Patch import attachURLs, attachDebugURLs
+from Util import update, populateEnvToSettings
+
 # Default SERVER_MODE values.
 DEVELOPMENT = 1
 STAGE = 2
@@ -142,17 +145,7 @@ def warnValue(k, settingsDict, defaults, value, msg=''):
             colored("(default value: %s)" % defaults[k], 'white',
                     attrs=['bold'])))
 
-def update(settingsDict, defaults, config=None):
-    """
-    Update settings by defaults if the key is not in settings.
-    
-    @param settingsDict Settings dict.
-    @param defaults Defaults dict to provide default value.
-    @param config Reserved.
-    """
-    for k, v in defaults.items():
-        if k not in settingsDict:
-            settingsDict[k] = v
+
             
 def checkImportPackage(packageName, settingsDict):
     """
@@ -202,43 +195,15 @@ def warnPackageDisable(packageName, settingsDict, defaults):
                           defaults, True,
                           'because %s are set.' % k)
                 break
-                
-def populateEnvToSettings(keys, settingsDict, setter=None, evalKeys=None):
-    """
-    Populate value in environment variables to settings.
-
-    @param keys Variable keys to find in environment variables.
-    @param settingsDict locals() in settings.py.
-    @param setter Function to decide how to set to settings.
-    @param evalKeys The keys in keys arguments which its value should be eval.
-    @return Set keys.
-    """
-    setKeys = []
     
-    for k in keys:
-        if k in os.environ:
-            print "%s found in environment variable, set to settings." % (
-                colored(k, 'yellow', attrs=['bold']))
-            
-            v = os.environ[k]
-            if evalKeys and k in evalKeys:
-                v = eval(v)
-                
-            if setter:
-                setter(k, v, settingsDict)
-            else:
-                settingsDict[k] = v
-                
-            setKeys.append(k)
-            
-    return setKeys
-    
-def attachSettings(settingsDict, warns=False, printDetail=True):
+def attachSettings(settingsDict, warns=True, printDetail=True):
     """
     Attach default settings to settings.py.
     It must be called in settings by passing locals().
 
     @param settingsDict locals() in settings.py.
+    @param warns Whether to show warnings or not.
+    @param printDetail Whether to print information or not.
     """
     settingsPath = os.path.abspath(settingsDict['__file__'])
     projectPath = os.path.abspath(os.path.join(
@@ -323,7 +288,7 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
     import socket
     
     if settingsDict['SERVER_MODE'] == DEVELOPMENT:
-        ALLOWED_HOSTS = (
+        ALLOWED_HOSTS = [
             'localhost', 
             '127.0.0.1',
             '::1', 
@@ -333,17 +298,16 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
             '.nuwainfo.com', 
             '.tracedig.com',
             '.%s' % '.'.join(socket.gethostname().split('.')[1:]),
-        )
+        ]
     else:
         ALLOWED_HOSTS = ['127.0.0.1', 'localhost']
         
-        if settingsDict['SITE_DOMAIN']:
-            siteDomain = settingsDict['SITE_DOMAIN']
-        else:
+    if settingsDict.get('ALLOWED_DOMAINS', None):
+        ALLOWED_HOSTS += list(settingsDict['ALLOWED_DOMAINS'])
+    else:
+        if settingsDict['SERVER_MODE'] != DEVELOPMENT:
             if warns:
-                warnWithout('SITE_DOMAIN', settingsDict, ALLOWED_HOSTS)
-        
-        ALLOWED_HOSTS.append(settingsDict['SITE_DOMAIN'])
+                require('ALLOWED_DOMAINS', settingsDict)
 
     adminDefaults = {
         'ADMINS': ADMINS,
@@ -465,7 +429,6 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
     #=========================================================================
 
     #=========================================================================
-
     # logging settings.
     # =======================================================================
     # https://docs.djangoproject.com/en/1.8/topics/logging/
@@ -524,10 +487,7 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
         'USE_X_FORWARDED_HOST': True
     }
     update(settingsDict, defaultForwardedHost)
-    
-    populateEnvToSettings((
-        'USE_X_FORWARDED_HOST',
-    ), settingsDict)
+
     #=========================================================================
     # I18n.
     i18nDefaults = {
@@ -541,7 +501,7 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
         'USE_I18N': True,
         'LANGUAGES': (
             ('zh-hant', 'Traditional Chinese'),
-            ('zh-cn', 'Simplified Chinese'),
+            ('zh-hans', 'Simplified Chinese'),
             ('en-us', 'English'),
         ),
         'LOCALE_PATHS': (
@@ -559,19 +519,12 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
 
     #=========================================================================
     # static files.
-    if settingsDict['SERVER_MODE'] == settingsDict['DEVELOPMENT']:
-        staticURL = '/static/'
-    elif settingsDict['SERVER_MODE'] == settingsDict['STAGE']:
-        staticURL = ('http://stage.nuwainfo.com/static/%s/' %
-                     settingsDict['APP_NAME'])
-    else: # PRODUCTION
-        staticURL = ('http://static.nuwainfo.com/static/%s/' %
-                     settingsDict['APP_NAME'])
+    staticURL = '/static/'
     
     if not DEBUG:   
         staticDefaults = {
             'STATIC_ROOT': os.path.join(projectPath, 'static'),
-            'STATIC_URL': '/static/',
+            'STATIC_URL': staticURL,
             'MEDIA_ROOT' : os.path.join(projectPath, 'media'),
             'MEDIA_URL' : '/media/',
         }
@@ -588,7 +541,7 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
             'STATICFILES_DIRS': (
                 os.path.join(projectPath, 'static'),
             ),
-            'STATIC_URL': '/static/',
+            'STATIC_URL': staticURL,
             'MEDIA_ROOT' : os.path.join(projectPath, 'media'),
             'MEDIA_URL' : '/media/',
         }
@@ -624,7 +577,6 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
     # URL.
     rootUrlDefaults = {
         'ROOT_URLCONF': '%s.urls' % projectName,
-        'WSGI_APPLICATION': '%s.urls' % projectName,
     }
 
     if warns:
@@ -633,6 +585,18 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
     update(settingsDict, rootUrlDefaults)
     #=========================================================================
 
+    #=========================================================================
+    # WSGI.
+    wsgiDefaults = {
+        'WSGI_APPLICATION': '%s.wsgi.application' % projectName,
+    }
+
+    if warns:
+        warnWithout('WSGI_APPLICATION', settingsDict, wsgiDefaults)
+    
+    update(settingsDict, wsgiDefaults)
+    #=========================================================================
+
     #=========================================================================
     # Site.
     siteDefaults = {
@@ -765,8 +729,12 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
     
     #=========================================================================
     # Iuno.member.
-    checkImportPackage('Iuno.member', settingsDict)
-    import Iuno.member
+    try:
+        checkImportPackage('Iuno.member', settingsDict)
+    except ImportError:
+        pass
+    else:
+        import Iuno.member
     
     iunoMemberDefaults = {
         'IUNO_MEMBER_ENABLE': False,
@@ -796,8 +764,12 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
 
     #=========================================================================
     #  Iuno.shop.
-    checkImportPackage('Iuno.shop', settingsDict)
-    import Iuno.shop
+    try:
+        checkImportPackage('Iuno.shop', settingsDict)
+    except ImportError:
+        pass
+    else:
+        import Iuno.shop
     
     iunoShopDefaults = {
         'IUNO_SHOP_ENABLE': False,
@@ -830,67 +802,30 @@ def attachSettings(settingsDict, warns=False, printDetail=True):
     if settingsDict['SERVER_MODE'] == settingsDict['DEVELOPMENT']:
         Patch.attachDebugSettings(settingsDict)
     #=========================================================================
-    #=========================================================================
-    # debug tool bar & django extensions
-    try:
-        import debug_toolbar
-        import django_extensions
-    except:
-        pass
-    else:
-        if DEBUG:
-            settingsDict['INSTALLED_APPS'] += ['django_extensions',]
-            settingsDict['INSTALLED_APPS']+= ['debug_toolbar', ]
-            settingsDict['MIDDLEWARE_CLASSES'] += ("debug_toolbar.middleware.DebugToolbarMiddleware", )
-            defaultInternalIP = {
-                'INTERNAL_IPS': ['127.0.0.1'],
-            }
-            update(settingsDict, defaultInternalIP)
-            
-            populateEnvToSettings((
-                'INTERNAL_IPS',
-            ), settingsDict)
 
     #=========================================================================
 
-    
-# Attach Iuno Urls
-def attachIunoUrls(settings, urlpatterns):
-    """
-    Attach Iuno related urlpatterns.
-    It must be called in urls.py by passing urlpatterns.
-
-    @param settings Django project's settings module.
-    @param urlpatterns urlpatterns in urls.py.
-    """
-
-    from django.conf.urls import url, include, patterns
-
-    urlpatterns += patterns('',
-        (r'^i18n/', include('django.conf.urls.i18n')),
-    )
-
-    if settings.DEBUG == False:
-        urlpatterns += patterns('',
-            url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {
-                'document_root': settings.MEDIA_ROOT,
-            })
-    )
-
-    try:
-        import debug_toolbar
-    except:
-        pass
-    else:
-        if settings.DEBUG:
-            urlpatterns += patterns('',
-                url(r'^__debug__/', include(debug_toolbar.urls)),
-            )
-
 # detect Server mode
 def detectServerMode(settingsDict):
-    SERVER_MODE = (DEVELOPMENT if 'SERVER_MODE' not in os.environ else
-               settingsDict[(os.environ['SERVER_MODE'])])
-    DEBUG = True if SERVER_MODE not in (STAGE, PRODUCTION) else False
+    """
+    Detect the project's current server mode. 
+    
+    @param settingsDict Settings dict.
+    """
+    _SERVER_MODE = (DEVELOPMENT 
+        if 'SERVER_MODE' not in os.environ 
+        else settingsDict[(os.environ['SERVER_MODE'])]
+    )
 
-    return SERVER_MODE, DEBUG
+    return _SERVER_MODE
+
+def detectDebug(settingsDict):
+    """
+    Detect the project's current debug mode. 
+    
+    @param settingsDict Settings dict.
+    """
+    _DEBUG = (True if settingsDict['SERVER_MODE'] not in (STAGE, PRODUCTION) 
+                   else False)
+
+    return _DEBUG
