@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9903 2017-04-23 13:53:33Z David $
+# $Id: __init__.py 9927 2017-04-29 14:17:02Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-23 21:53:33 +0800 (Sun, 23 Apr 2017) $
-# $Revision: 9903 $
+# $Date: 2017-04-29 22:17:02 +0800 (Sat, 29 Apr 2017) $
+# $Revision: 9927 $
 
 import os
 import sys
@@ -212,10 +212,13 @@ def attachShopURLs(settings, urlpatterns):
     @param urlpatterns urlpatterns in urls.py.
     """
 
-    from django.conf.urls import url, patterns
+    from django.conf.urls import url, patterns, include
     from oscar.app import application as shop
-
+    
     urlpatterns += patterns('',
+        # the i18n is the default url settings of django oscar, but generally
+        # we are not used.
+        (r'^i18n/', include('django.conf.urls.i18n')),
         (r'^shop/', shop.urls),
     )
 
